Module git_historian::parsing
[−]
[src]
Parses git log --name-status to generate a stream of file changes
in Git history
Originally the Rust bindings for libgit2 was used, but there is currently no clean or efficient way for libgit to generate diffs for merges (i.e. only the changes resulting from conflict resolution) as Git does.
Structs
| ParsedCommit |
Info about a commit pulled from |
Functions
| get_history |
Parses the Git history and emits a series of |