Struct git_historian::FileDelta
[−]
[src]
pub struct FileDelta {
pub change: Change,
pub path: String,
pub from: String,
}A change made to a given file in a commit
Fields
change: Change
The change type
path: String
The current path of the file
from: String
The previous path of the file if the change is a rename or copy, and an empty string otherwise